@@ -263,6 +263,7 @@ struct marpaESLIF {
 #ifdef HAVE_LOCALE_H
   struct lconv           *lconvp;
 #endif
+  char                    decimalPointc;
   const uint8_t          *tablesp;                     /* Output of pcre2_maketables */
 #ifdef MARPAESLIF_HAVE_LONG_LONG
   size_t                  llongmincharsl;              /* Number of digits of LLONG_MIN */
@@ -300,7 +301,6 @@ struct marpaESLIFGrammar {
   short                      hasPseudoTerminalb; /* Any pseudo terminal in the grammar ? */
   short                      hasEofPseudoTerminalb; /* Any :eof terminal in the grammar ? */
   short                      hasEolPseudoTerminalb; /* Any :eol terminal in the grammar ? */
-  short                      jsonStrictb;        /* For embedded JSON grammar, remember if this is strict JSON or not */
 };
 
 struct marpaESLIF_meta {
